<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/core/ui/about.cpp" line="40"/>
        <source>About</source>
        <translation>Rakenduse teave</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="41"/>
        <source>Thanks</source>
        <translation>Tänud</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="42"/>
        <source>Help us</source>
        <translation>Aita meid</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="99"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>on mitmetes operatsioonisüsteemides toimiv kiire töölauapildistamise rakendus.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="101"/>
        <source>It is a light and powerful application, written in Qt.</source>
        <translation>Tegemist on väikese, kuid tõhust Qt-teekide baasil tehtud rakendusega.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="33"/>
        <source>using Qt %1</source>
        <translation>kasutades Qt-teeke %1</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="104"/>
        <source>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
        <translation>Veebisait - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="107"/>
        <source>Licensed under the &lt;a href=%1&gt;GPL v2&lt;/a&gt;</source>
        <translation>Avaldatud &lt;a href=%1&gt;GPL v2&lt;/a&gt; litsentsi alusel</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="111"/>
        <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
        <translation>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="113"/>
        <source>Copyright &amp;copy; 2013-2025, LXQt team</source>
        <translation>Autoriõigused &amp;copy; 2013-2025, LXQt tiim</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="120"/>
        <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
        <translation>Kui tahad, siis liitu meiega ja aita rakendust arendada. Võid seda võtta kutsena.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="123"/>
        <source>What you can do?</source>
        <translation>Mida sa saad teha?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="126"/>
        <source>Translate ScreenGrab to other languages</source>
        <translation>Tõlgi ScreenGrab teistesse keeltesse</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="127"/>
        <source>Make suggestions for next releases</source>
        <translation>Tee ettepanekuid tulevaste versioonide jaoks</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="128"/>
        <source>Report bugs and issues</source>
        <translation>Teata vigadest ja probleemidest</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="131"/>
        <source>Bug tracker</source>
        <translation>Veahaldus</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="142"/>
        <source>Special thanks to:</source>
        <translation>Eraldi soovime tänada:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="144"/>
        <source>for creating ScreenGrab</source>
        <translation>ScreenGrabi loomise eest</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="145"/>
        <source>for supporting wlr screencopy protocol</source>
        <translation>wlr ekraanikopeerimise protokolli toe eest</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="190"/>
        <source>Directory %1 does not exist. Do you want to create it?</source>
        <translation>%1 kausta pole olemas. Kas soovid seda luua?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="191"/>
        <location filename="../src/core/ui/configwidget.cpp" line="280"/>
        <source>Warning</source>
        <translation>Hoiatus</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="268"/>
        <source>Select directory</source>
        <translation>Vali kaust</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="279"/>
        <source>Do you want to reset the settings to the defaults?</source>
        <translation>Kas sa soovid need seadistused lähtestada?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="313"/>
        <source>Example: </source>
        <translation>Näide: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="354"/>
        <source>This key is already used in ScreenGrab! Please select another.</source>
        <translation>ScreenGrab juba kasutab seda klahvi! Palun vali midagi muud.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="372"/>
        <source>This key is not supported on your system!</source>
        <translation>Sellist klahvi sinu arvuti operatsioonisüsteem ei toeta!</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="392"/>
        <source>Error</source>
        <translation>Viga</translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../src/core/core.cpp" line="66"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>on mitmetes operatsioonisüsteemides toimiv kiire töölauapildistamise rakendus.</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="70"/>
        <source>Take a fullscreen screenshot</source>
        <translation>Tee ekraanitõmmis kogu ekraanist</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="74"/>
        <source>Take a screenshot of the active window</source>
        <translation>Tee ekraanitõmmis kasutusel olevast aknast</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="78"/>
        <source>Take a screenshot of a selection of the screen</source>
        <translation>Tee ekraanitõmmis ekraani osast</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="82"/>
        <source>Run the application with a hidden main window</source>
        <translation>Käivita rakendus nii, et põhiaken on peidetud</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="85"/>
        <source>Save screenshot and exit, without showing window</source>
        <translation>Salvesta ekraanitõmmis ja välju ilma akent kuvamata</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="575"/>
        <source>Saved</source>
        <translation>Salvesin</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="575"/>
        <source>Saved to </source>
        <translation>Salvestasin faili </translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="597"/>
        <source>Name of saved file is copied to the clipboard</source>
        <translation>Salvestatud faili nime kopeerisin lõikelauale</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="603"/>
        <source>Path to saved file is copied to the clipboard</source>
        <translation>Salvestatud faili asukoha kopeerisin lõikelauale</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="626"/>
        <source>Copied</source>
        <translation>Kopeerisin</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="626"/>
        <source>Screenshot is copied to clipboard</source>
        <translation>Ekraanitõmmise kopeerisin lõikelauale</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="14"/>
        <source>ScreenGrab</source>
        <translation>ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="73"/>
        <source>Screen:</source>
        <translation>Ekraan:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="105"/>
        <source>Type:</source>
        <translation>Tüüp:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="115"/>
        <source>Type of screenshot</source>
        <translation>Ekraanitõmmise tüüp</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="122"/>
        <source>Full screen</source>
        <translation>Kogu ekraan</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="127"/>
        <source>Window</source>
        <translation>Aken</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="132"/>
        <source>Screen area</source>
        <translation>Ekraani osa</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="137"/>
        <source>Last selected area</source>
        <translation>Viimati valitud ala</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="167"/>
        <source>Delay:</source>
        <translation>Viivitus:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="180"/>
        <source>Delay in seconds before taking screenshot</source>
        <translation>Viivitus sekundites enne ekraanitõmmise tegemist</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="183"/>
        <source>None</source>
        <translation>Puudub</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="186"/>
        <source> sec</source>
        <translation> sek</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="245"/>
        <source>Zoom area around mouse</source>
        <translation>Suumi hiirekursorit ümbritsevat piirkonda</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="252"/>
        <source>No window decoration</source>
        <translation>Ära salvesta akna äärt ja päiseriba</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="259"/>
        <source>Include mouse pointer</source>
        <translation>Salvesta ka hiirekursor</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="291"/>
        <source>toolBar</source>
        <translation>tööriistariba</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="44"/>
        <source>New</source>
        <translation>Uus</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
        <source>Save</source>
        <translation>Salvesta</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
        <source>Copy</source>
        <translation>Kopeeri</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
        <source>Options</source>
        <translation>Seadistused</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
        <source>About</source>
        <translation>Rakenduse teave</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
        <source>Quit</source>
        <translation>Sulge</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="358"/>
        <source>Screenshot </source>
        <translation>Ekraanitõmmis </translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="362"/>
        <source>Double click to open screenshot in external default image viewer</source>
        <translation>Topeltklõpsuga saad avada ekraanitõmmise välises rakenduses</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="371"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="540"/>
        <source>Hide</source>
        <translation>Peida</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="547"/>
        <source>Show</source>
        <translation>Näita</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="616"/>
        <source>%1 Files</source>
        <translation>%1 faili</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="638"/>
        <source>Save As...</source>
        <translation>Salvesta kui...</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/core/regionselect.cpp" line="148"/>
        <source>Click and drag to draw a rectangle,
double click or press Enter
to take a screenshot,
or press Escape to cancel.</source>
        <translation>Ristküliku joonistamiseks klõpsa ja lohista,
ekraanipildi tegemiseks
topeltklõpsa või vajuta sisestusklahvi
või katkestamiseks vajuta „Esc“ klahvi.</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="245"/>
        <source>Click and drag to draw a rectangle,
right click to fit to edges,
double click or press Enter
to take a screenshot.</source>
        <translation>Pildistatava ristküliku joonistamiseks kliki hiirega ja lohista,
parema klahvi klõpsuga saad ääri sättida,
topeltklõps või Enter-klahvi vajutus
teeb ekraanipildi.</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="305"/>
        <source>%1 x %2 pixels </source>
        <translation>%1 x %2 pikselit </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="35"/>
        <source>External edit</source>
        <translation>Kasuta välist rakendust</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="46"/>
        <source>Edit in...</source>
        <translation>Muuda rakenduses...</translation>
    </message>
</context>
<context>
    <name>aboutWidget</name>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="118"/>
        <source>About Qt</source>
        <translation>Qt teave</translation>
    </message>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="144"/>
        <source>Close</source>
        <translation>Sulge</translation>
    </message>
</context>
<context>
    <name>configwidget</name>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="26"/>
        <location filename="../src/core/ui/configwidget.ui" line="536"/>
        <source>Options</source>
        <translation>Seadistused</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="35"/>
        <source>Main</source>
        <translation>Põhiseadistused</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="40"/>
        <source>Advanced</source>
        <translation>Lisaseadistused</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="45"/>
        <source>System tray</source>
        <translation>Süsteemisalv</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="50"/>
        <source>Shortcuts</source>
        <translation>Kiirklahvid</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="74"/>
        <source>Default save directory</source>
        <translation>Vaikimisi kaust salvestamiseks</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="80"/>
        <source>Path to default selection dir for saving</source>
        <translation>Kaust, kuhu vaikimisi salvestame ekraanitõmmised</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="93"/>
        <source>Browse filesystem</source>
        <translation>Sirvi failisüsteemi</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="96"/>
        <source>Browse</source>
        <translation>Sirvi</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="106"/>
        <source>Default file</source>
        <translation>Salvestatav fail</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="119"/>
        <source>Name:</source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="126"/>
        <source>Default filename</source>
        <translation>Vaikimisi pakutav failinimi</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="137"/>
        <source>Format</source>
        <translation>Vorming</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="150"/>
        <source>Default saving image format</source>
        <translation>Vaikimisi vorming faili salvestamiseks</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="169"/>
        <source>Copy file name to the clipboard when saving</source>
        <translation>Salvestamisel kopeeri failinimi lõikelauale</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="183"/>
        <source>Do not copy</source>
        <translation>Ära kopeeri</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="188"/>
        <source>Copy file name only</source>
        <translation>Kopeeri vaid faili nimi</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="193"/>
        <source>Copy full file path</source>
        <translation>Kopeeri faili nimi koos asukohaga</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="203"/>
        <source>Image quality</source>
        <translation>Pildikvaliteet</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="209"/>
        <source>Image quality (1 - small file, 100 - high quality)</source>
        <translation>Salvestatava pildi kvaliteet (1 - väike, aga kehv fail; 100 - suur, aga väga kvaliteetne fail)</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="274"/>
        <source>Inserting current date time into saved filename</source>
        <translation>Lisa salvestatavale failinimele ajatempel</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="277"/>
        <source>Insert current date and time in file name</source>
        <translation>Lisa failinimele salvestamise hetke ajatempel</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="286"/>
        <source>Template: </source>
        <translation>Ajatempli mall: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="311"/>
        <source>Example: </source>
        <translation>Näiteks: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="321"/>
        <source>Automatically saving screenshots in grabbing process</source>
        <translation>Salvesta ekraanitõmmised automaatselt etteantud kausta</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="324"/>
        <source>Autosave screenshot</source>
        <translation>Salvesta ekraanitõmmised automaatselt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="336"/>
        <source>Save first screenshot</source>
        <translation>Salvesta esimene ekraanitõmmis</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="345"/>
        <source>Allow run multiplies copy of ScreenGrab</source>
        <translation>Luba avada mitu ScreenGrab&apos;i programmi akent</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="348"/>
        <source>Allow multiple instances of ScreenGrab</source>
        <translation>Luba käivitada mitu ScreenGrab&apos;i</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="355"/>
        <source>Open in external viewer on double click</source>
        <translation>Topeltklõpsuga ava ekraanitõmmis välise rakendusega mis võimaldab pilti vaadata või töödelda</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="358"/>
        <source>Enable external viewer</source>
        <translation>Ava välise rakendusega</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="365"/>
        <source>If this is unchecked, the selected area
might become larger to fit to outer edges</source>
        <translation>Kui see valik pole kasutusel, siis valitud ala
võib olla liiga suur mahtumaks välispiiridesse</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="369"/>
        <source>Fit to edges inside selected area by right clicking</source>
        <translation>Parema klõpsuga mahuta pilt valitud alasse</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="376"/>
        <source>With multiple screens</source>
        <translation>Mitme ekraani puhul</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="379"/>
        <source>Remember last selected screen in next session</source>
        <translation>Jäta viimativalitud ekraan järgmiseks sessiooniks meelde</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="386"/>
        <source>Notify on saving and copying</source>
        <translation>Teavita salvestamisest ja kopeerimisest</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="395"/>
        <source>Duration:</source>
        <translation>Kestus:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="462"/>
        <source>Show ScreenGrab in the system tray</source>
        <translation>Näita ScreenGrab&apos;i ikooni süsteemisalves</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="402"/>
        <source> sec</source>
        <translation> sek</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="469"/>
        <source>Minimize to tray on click close button</source>
        <translation>Sulgemise nupu vajutamine ei sulge rakendust, vaid lisab ScreenGrab&apos;i süsteemisalve</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="472"/>
        <source>Minimize to tray when closing</source>
        <translation>Sulgemise nupp lisab süsteemisalve</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="511"/>
        <source>Action</source>
        <translation>Tegevus</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="516"/>
        <source>Shortcut</source>
        <translation>Kiirklahv</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="521"/>
        <source>New screen</source>
        <translation>Uus ekraanitõmmis</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="526"/>
        <source>Save screen</source>
        <translation>Salvesta ekraanitõmmis</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="531"/>
        <source>Copy screen</source>
        <translation>Kopeeri ekraanitõmmis</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="541"/>
        <source>Quit</source>
        <translation>Sulge</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="551"/>
        <source>Selected shortcut:</source>
        <translation>Valitud kiirklahv:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="558"/>
        <source>Not defined</source>
        <translation>Määratlemata</translation>
    </message>
</context>
</TS>
